==> LIM-cpu-1.0.0.tar.gz: LIM-cpu-1.0.0/README.md <==
<div align="center" id="top"> 
  <img src="./asm2bin.png" alt="LIM Assembler" />

  &#xa0;

  <!-- <a href="https://assembler2.netlify.app">Demo</a> -->
</div>

<h1 align="center">LIM Assembler</h1>

<p align="center">
  <img alt="Github top language" src="https://img.shields.io/github/languages/top/Spud304/LIM-Assembler?color=56BEB8">

  <img alt="Github language count" src="https://img.shields.io/github/languages/count/Spud304/LIM-Assembler?color=56BEB8">

  <img alt="Repository size" src="https://img.shields.io/github/repo-size/Spud304/LIM-Assembler?color=56BEB8">

  <img alt="License" src="https://img.shields.io/github/license/Spud304/LIM-Assembler?color=56BEB8">

  <!-- <img alt="Github issues" src="https://img.shields.io/github/issues/{{YOUR_GITHUB_USERNAME}}/assembler2?color=56BEB8" /> -->

  <!-- <img alt="Github forks" src="https://img.shields.io/github/forks/{{YOUR_GITHUB_USERNAME}}/assembler2?color=56BEB8" /> -->

  <!-- <img alt="Github stars" src="https://img.shields.io/github/stars/{{YOUR_GITHUB_USERNAME}}/assembler2?color=56BEB8" /> -->
</p>

<!-- Status -->

<!-- <h4 align="center"> 
	🚧  Assembler2 🚀 Under construction...  🚧
</h4> 

<hr> -->

<p align="center">
  <a href="#dart-about">About</a> &#xa0; | &#xa0; 
  <a href="#sparkles-features">Features</a> &#xa0; | &#xa0;
  <a href="#white_check_mark-requirements">Requirements</a> &#xa0; | &#xa0;
  <a href="#checkered_flag-starting">Starting</a> &#xa0; | &#xa0;
  <a href="#memo-license">License</a> &#xa0; | &#xa0;
  <a href="https://github.com/Spud304" target="_blank">Author</a>
</p>

<br>

## About ##

A Simple assembler for the LIM CPU, Developed by Me with help from theerror07

## Features ##

Var Definition;\
Memory Allocation Warning;\
Cool timer;

## Requirements ##

Before starting :checkered_flag:, you need to have [Python](https://www.python.org/)

## Using Pip ##

```bash
$ pip install LIM
```

## Starting ##

```bash
# Clone this project
$ git clone https://github.com/Spud304/LIM-Assembler

# Access
$ cd LIM-Assembler

# Run
$ python3 LIM.py

```

## Compile ##

If you want an .exe of your edited code, use [Pyinstaller](https://www.pyinstaller.org/)

```bash

$ cd LIM-Assembler

$ pyinstaller --onefile -i asm2bin.ico LIM.py

```

Then in the build folder your new and improved .exe will be created

## License ##

This project is under license from MIT. For more details, see the [LICENSE](LICENSE.md) file.


Made with :heart: by <a href="https://github.com/Spud304" target="_blank">Spud</a>

&#xa0;

<a href="#top">Back to top</a>

==> LIM-cpu-1.0.2.tar.gz: LIM-cpu-1.0.2/README.md <==
<div align="center" id="top"> 
  <img src="./asm2bin.png" alt="LIM Assembler" />

  &#xa0;

  <!-- <a href="https://assembler2.netlify.app">Demo</a> -->
</div>

<h1 align="center">LIM Assembler</h1>

<p align="center">
  <img alt="Github top language" src="https://img.shields.io/github/languages/top/Spud304/LIM-Assembler?color=56BEB8">

  <img alt="Github language count" src="https://img.shields.io/github/languages/count/Spud304/LIM-Assembler?color=56BEB8">

  <img alt="Repository size" src="https://img.shields.io/github/repo-size/Spud304/LIM-Assembler?color=56BEB8">

  <img alt="License" src="https://img.shields.io/github/license/Spud304/LIM-Assembler?color=56BEB8">

  <!-- <img alt="Github issues" src="https://img.shields.io/github/issues/{{YOUR_GITHUB_USERNAME}}/assembler2?color=56BEB8" /> -->

  <!-- <img alt="Github forks" src="https://img.shields.io/github/forks/{{YOUR_GITHUB_USERNAME}}/assembler2?color=56BEB8" /> -->

  <!-- <img alt="Github stars" src="https://img.shields.io/github/stars/{{YOUR_GITHUB_USERNAME}}/assembler2?color=56BEB8" /> -->
</p>

<!-- Status -->

<!-- <h4 align="center"> 
	🚧  Assembler2 🚀 Under construction...  🚧
</h4> 

<hr> -->

<p align="center">
  <a href="#about">About</a> &#xa0; | &#xa0; 
  <a href="#features">Features</a> &#xa0; | &#xa0;
  <a href="#requirements">Requirements</a> &#xa0; | &#xa0;
  <a href="#installation">Installation</a> &#xa0; | &#xa0;
  <a href="#starting">Starting</a> &#xa0; | &#xa0;
  <a href="#license">License</a> &#xa0; | &#xa0;
  <a href="https://github.com/Spud304" target="_blank">Author</a>
</p>

<br>

## About ##

A Simple assembler for the LIM CPU, Developed by Henry Price with help from theerror07

## Features ##

Var Definition;\
Memory Allocation Warning;\
Cool timer;

## Requirements ##

Before starting, you need to have [Python](https://www.python.org/)

## Installation ##

```bash
$ pip install LIM-cpu
```

## Starting ##

```bash
$ LIM-cpu <file_path_here> <debug_mode (optional)>
```
High.bin and low.bin will be placed in the same dir as the file

## License ##

This project is under license from MIT. For more details, see the [LICENSE](LICENSE.md) file.
Made by <a href="https://github.com/Spud304" target="_blank">Spud</a>

&#xa0;

<a href="#top">Back to top</a>
